class GameSceneBehavior extends Sup.Behavior {
	
	awake() {
		// Reset the global vars
		g_bgm = null;
		g_pause = false;
		g_blockPlayerMove = false;
		g_proutLives = 3;
		g_ui = {
			time: g_maxTime,
			health: g_maxTime,
			win: false
		};
		
		if (g_bgm != null) {
			g_bgm.stop();
		}
		
		// Load the level
		Sup.appendScene("Scenes/Scene_Level" + g_level);
		
		// Run the timer for time and health
		this.runTimer();
	}

	update() {
		// Go back to title if escape in pause
		if (Sup.Input.wasKeyJustReleased("ESCAPE") && g_pause) {
			g_bgm.stop();
			g_bgm = null;
			Sup.loadScene("Scenes/Scene_Title");
		}
		
		// Toggle the pause
		if (Sup.Input.wasKeyJustReleased("SPACE") || Sup.Input.wasKeyJustReleased("ESCAPE")) {
			g_pause = !g_pause;
			
			if (g_pause) {
				g_bgm.pause();
				Sup.clearInterval(g_timer);
			} else {
				g_bgm.play();
				this.runTimer();
			}
		}
		
		// Debug key
		if (Sup.Input.wasKeyJustReleased("E")) {
			g_ui.time -= 10;
			g_ui.health -= 10;
		}
		
		// Cancel if the game is paused
		if (g_pause) {
			return;
		}
		
		// Go to game over if time or health are out
		if (g_ui.time <= 0 || g_ui.health <= 0 || g_proutLives == 0) {
			g_bgm.stop();
			g_bgm = null;
			Sup.clearInterval(g_timer);
			Sup.loadScene("Scenes/Scene_GameOver");
		}
	}

	private runTimer() {
		// Clear the timer if it's already running
		if (g_timer != null) {
			Sup.clearInterval(g_timer);
		}
		
		// Update the values each second unless the player won
		g_timer = Sup.setInterval(1000, () => {
			Sup.log("time", g_ui.time);
			if (!g_ui.win) {
				g_ui.time -= 1;
				g_ui.health -= 1;
			}
		});
	}
}
Sup.registerBehavior(GameSceneBehavior);
