class SecretaireBehavior extends Sup.Behavior {
	
	public direction: string = "bottom";
	public distance: number = 2;
	private speed: number = 0.02;
	private reverse: boolean = false;
	private startX: number;
	private startY: number;
	
	awake() {
		this.startX = this.actor.getX();
		this.startY = this.actor.getY();
		this.actor.spriteRenderer.setAnimation("Walk").playAnimation(true);
	}

	update() {
		// Get the current velocity of the actor
		let velocity = this.actor.arcadeBody2D.getVelocity();
		let angle = 0;
		
		// Cancel if the game is paused
		if (g_pause) {
			velocity.x = 0;
			velocity.y = 0;
			this.actor.arcadeBody2D.setVelocity(velocity);
			this.actor.spriteRenderer.setAnimation("Idle");
			return;
		}
		
		// Always show the walking animation
		this.actor.spriteRenderer.setAnimation("Walk", true);
		
		// Move to the top / bottom
		if ((this.direction == "top" && !this.reverse) || (this.direction == "bottom" && this.reverse)) {
			velocity.y = this.speed;
			angle = 0 * RAD;
			
			if (this.actor.getY() - this.startY >= this.distance) {
				this.startY = this.actor.getY();
				this.reverse = (this.direction == "top") ? true : false;
			}
		} else if ((this.direction == "bottom" && !this.reverse) || (this.direction == "top" && this.reverse)) {
			velocity.y = -this.speed;
			angle = 180 * RAD;
			
			if (this.startY - this.actor.getY() >= this.distance) {
				this.startY = this.actor.getY();
				this.reverse = (this.direction == "bottom") ? true : false;
			}
		}
		
		// Move to the left / right
		if ((this.direction == "left" && !this.reverse) || (this.direction == "right" && this.reverse)) {
			velocity.x = -this.speed;
			angle = 90 * RAD;
			
			if (this.startX - this.actor.getX() >= this.distance) {
				this.startX = this.actor.getX();
				this.reverse = (this.direction == "left") ? true : false;
			}
		} else if ((this.direction == "right" && !this.reverse) || (this.direction == "left" && this.reverse)) {
			velocity.x = this.speed;
			angle = 270 * RAD;
			
			if (this.actor.getX() - this.startX >= this.distance) {
				this.startX = this.actor.getX();
				this.reverse = (this.direction == "right") ? true : false;
			}
		}
		
		// Apply the player rotation
		this.actor.setEulerZ(angle);
		
		// Apply the actor velocity
		this.actor.arcadeBody2D.setVelocity(velocity);
	}
}
Sup.registerBehavior(SecretaireBehavior);
