class UIBehavior extends Sup.Behavior {
	
	private healthTop: number;
	private isIntroBGM: boolean = false;
	private bgmName: string = "";
	
	awake() {
		this.healthTop = this.actor.getChild("Health_Value").getY();
		
		// Start the game BGM
		this.bgmName = "Intro";
		g_bgm = Sup.Audio.playSound("Sounds/Sound_Intro", g_volume_bgm);
		g_bgm.play();
		
		// Set the face animation
		this.actor.getChild("Face").spriteRenderer.setSprite("Sprites/Player/Sprite_" + g_gender + "_Face");
		this.actor.getChild("Face").spriteRenderer.setAnimation("Running_0", true);
		
		// Hide the first tutorial
		Sup.setTimeout(5 * 1000, () => {
			this.actor.getChild("Tuto1").setVisible(false);
			this.actor.getChild("Tuto_Back").setVisible(false);
		});
		
		// Show the second tutorial
		Sup.setTimeout(15 * 1000, () => {
			this.actor.getChild("Tuto2").setVisible(true);
			this.actor.getChild("Tuto_Back").setVisible(true);
		});
		
		// Hide the second tutorial
		Sup.setTimeout(20 * 1000, () => {
			this.actor.getChild("Tuto2").setVisible(false);
			this.actor.getChild("Tuto_Back").setVisible(false);
		});
	}

	update() {
		// Cancel if the game is paused and freeze the UI
		if (g_pause) {
			this.actor.getChild("Pause").setVisible(true);
			this.actor.getChild("Pause_Desc").setVisible(true);
			this.actor.getChild("Pause_Back").setVisible(true);
			this.actor.getChild("Face").spriteRenderer.pauseAnimation();
			return;
		} else {
			this.actor.getChild("Pause").setVisible(false);
			this.actor.getChild("Pause_Desc").setVisible(false);
			this.actor.getChild("Pause_Back").setVisible(false);
			this.actor.getChild("Face").spriteRenderer.playAnimation(true);
		}
		
		// Set the state of the prout lives
		for (let i = 1; i <= 3; i++) {
			if (i > (3 - g_proutLives)) {
				this.actor.getChild("ProutLives").getChild("ProutLive_" + i).spriteRenderer.setAnimation("On", false);
			} else {
				this.actor.getChild("ProutLives").getChild("ProutLive_" + i).spriteRenderer.setAnimation("Off", false);
			}
		}
		
		// Set the timer text
		let minutes = Math.floor((g_ui.time / 60) % 60);
		let seconds:any = Math.floor((g_ui.time) % 60);
		seconds = (seconds < 10) ? "0" + seconds : seconds;
		this.actor.getChild("Timer").textRenderer.setText(minutes + ":" + seconds);
		this.actor.getChild("Timer_Shadow").textRenderer.setText(minutes + ":" + seconds);

		// Set the health value position
		let offsetY = (((g_ui.health - g_maxTime) / 100) * 0.7);
		this.actor.getChild("Health_Value").setY(this.healthTop + offsetY);

		// Set the face animation and background music
		let timeSplit = g_maxTime / 3;
		if (g_ui.time < timeSplit * 1) {
			// Palier 3
			this.actor.getChild("Face").spriteRenderer.setAnimation("Running_2");
			
			if (this.bgmName != "Palier3") {
				this.bgmName = "Palier3";
				g_bgm.stop();
				g_bgm = Sup.Audio.playSound("Sounds/Sound_Palier3", g_volume_bgm, {loop: true});
				g_bgm.play();
			}
		} else if (g_ui.time < timeSplit * 2) {
			// Palier 2
			this.actor.getChild("Face").spriteRenderer.setAnimation("Running_1");
			
			if (this.bgmName != "Palier2") {
				this.bgmName = "Palier2";
				g_bgm.stop();
				g_bgm = Sup.Audio.playSound("Sounds/Sound_Palier2", g_volume_bgm, {loop: true});
				g_bgm.play();
			}
		} else {
			// Palier 1
			if (this.bgmName == "Intro" && !g_bgm.isPlaying()) {
				this.bgmName = "Palier1";
				g_bgm = Sup.Audio.playSound("Sounds/Sound_Palier1", g_volume_bgm, {loop: true});
				g_bgm.play();
			}
		}
		
		// Set the winning animation
		if (g_ui.win) {
			this.actor.getChild("Win").setVisible(true);
			this.actor.getChild("Pause_Back").setVisible(true);
			this.actor.getChild("Face").spriteRenderer.setAnimation("Happy");
		}
	}
}
Sup.registerBehavior(UIBehavior);
